


pro netscape_control, item, remote, which_netscape=which_netscape, $
		      install=install, noinstall=noinstall, $
		      iconic=iconic, id=id, display=display, $
		      nosplash=nosplash, splash=splash, $
		      raise=raise, noraise=noraise, geometry=geometry, $
		      nospawn=nospawn, $
                      nobackground=nobackground, $
                      openurl=openurl, openfile=openfile, $
		      netscape_command=netscape_command, $
		      loud=loud, debug=debug
;+
;   Name: netscape_control
;
;   Purpose: control Netscape client process(es) from within SSW/IDL
;
;   Input Parameters:
;      item    - optional url or file name for action (ex: to open)
;      remote - optional remote control command
;      SEE: http://home.netscape.com/newsref/std/x-remote.html
;
;   Keyword Parameters:
;      which_netscape          - Full Netscape path (default assume in $path)
;      install                 - privatecolor map 
;      noinstall               - shared color map 
;      iconic                  - start iconified
;      id                      window id
;      display                 X Client(s) Default=current OR last specified
;                              [may be an array]
;      splash                  include license info (default=NOSPLASH)
;      raise                   raise Netscape window
;      noraise                 do not raise Netscape window
;      geometry                WxH+X+Y - position and size the window
;      openURL                 open URL  (via ITEM)
;      openFile                open File (via ITEM) 
;      nospawn                 Do not spawn the command 
;      nobackground            Do not background command
;      netscape_command (OUTPUT) - implied/spawned command
;
;   Calling Sequence:
;      IDL> netscape_control [,URL] [,display=IP] [,/install] [,/iconic], $
;                            [,/openURL] [,/nobackground] [/noraise] ...
;
;   Calling Example:
;    1. Initial Call - open a Netscape Client on the designated display
;                      Optionally supply an initial URL
;    IDL> netscape_control,'http://www.lmsal.com/SXT/html/First_Light.html',$
;                           display='sxt1.lmsal.com', /install
;    2. Open a new URL in an existing Netscape Client
;    IDL> netscape_control,'http://vestige.lmsal.com/TRACE/last_movies/', $
;                          /openURL
;         a) display defaults to previous call
;         b) uses 'remote' control capabilities of Netscape; 'openURL' in this
;            example.
;             
;   Restrictions:
;      X Client must permit X requests from the Server (IDL caller)
;
;   History:
;      25-April-2000  S.L.Freeland - "leverage" browser technologies 
;                                    simplify SSWIDL<->Netscape interface
;                     Initially for automated QKL/NRT display of solar data
;                           
;-
common netscape_control_blk, last_display, last_id
  
debug=keyword_set(debug)
loud=debug or keyword_set(loud)

if not data_chk(which_netscape,/string) then which_netscape='netscape'

; ------------- display windows IDs and X Server options
xid=''
if data_chk(id,/string) then xid='id '+id            ; Window ID supplied?
xdisplay=''
if data_chk(display,/string) then begin              ; X Client(s) supplied? 
   xdisplay='-display ' + display
   xdisplay=$
     xdisplay+(['',':0'])(strpos(xdisplay,':0') ne strlen(xdisplay)-2)
   last_display=xdisplay  
endif else if data_chk(last_display,/string) then xdisplay=last_display
; -----------------------------------------------------------------------

; ----------  binary keyword command options ---------------------------
xinstall=(['','-install'])(keyword_set(install))         ; private colors?
xicon=(['','-iconic'])(keyword_set(iconic))              ; iconify on start?
xraise=(['','-noraise'])(keyword_set(noraise))           ; dont raise?
xsplash=(['-no-about-splash',''])(keyword_set(splash))   ; include lic info?
xback=([' &',''])(keyword_set(nobackground))             ; dont background?
; -----------------------------------------------------------------------

netscape_command=strcompress(arr2str( $
  [which_netscape,xid,xinstall,xicon,xraise,xsplash],' ')) + $  ; command
		                      ' ' + xdisplay            ; ->display(s)

; -------- look for/assemble remote commands or URL input --------------
if not keyword_set(item) then item=''                     ; force string oper.
case 1 of
   data_chk(remote,/string): $
	 remcmd="-remote " + str_replace(remote,'-remote','') ; user remote cmd
   keyword_set(openurl) and data_chk(item,/string): $         ; remcmd=openURL?
		remcmd="-remote 'openURL(" + item(0) + ")'"
   keyword_set(openfile) and data_chk(item,/string): $        ; remcmd=openFile?
		remcmd="-remote 'openFile(" + item(0) + ")'"
   data_chk(item,/string): remcmd=item                        ; URL passed?
   else: remcmd=''
endcase
netscape_command=netscape_command + ' ' + remcmd + ' ' + xback ; remote/back
; ----------------------------------------------------------------------

; -------- spawn command(s) if not told otherwise -------------------
if not keyword_set(nospawn) then begin
   sout=''
   for i=0,n_elements(netscape_command)-1 do begin 
      if loud then box_message,'Executing: ' + netscape_command(i)
      spawn,netscape_command(i),soutx
      sout=[sout,soutx]                      ; log output
   endfor
endif else if loud then box_message,['Commands','   ' + netscape_command]
; ----------------------------------------------------------------------

if debug then stop
return
end
